@@ -24,12 +24,18 @@ Usage::
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_cloudwatch.literals import (
+    AlarmType,
+    HistoryItemType,
+    RecentlyActive,
+    ScanBy,
+    StateValue,
+)
 from mypy_boto3_cloudwatch.type_defs import (
     DescribeAlarmHistoryOutputTypeDef,
     DescribeAlarmsOutputTypeDef,
@@ -42,12 +48,6 @@ from mypy_boto3_cloudwatch.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeAlarmHistoryPaginator",
     "DescribeAlarmsPaginator",
@@ -59,48 +59,48 @@ __all__ = (
 
 class DescribeAlarmHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
     """
 
     def paginate(
         self,
         AlarmName: str = None,
-        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
-        HistoryItemType: Literal["ConfigurationUpdate", "StateUpdate", "Action"] = None,
+        AlarmTypes: List[AlarmType] = None,
+        HistoryItemType: HistoryItemType = None,
         StartDate: datetime = None,
         EndDate: datetime = None,
-        ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
+        ScanBy: ScanBy = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmHistoryOutputTypeDef]:
         """
-        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
         """
 
 
 class DescribeAlarmsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
     """
 
     def paginate(
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[Literal["CompositeAlarm", "MetricAlarm"]] = None,
+        AlarmTypes: List[AlarmType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
-        StateValue: Literal["OK", "ALARM", "INSUFFICIENT_DATA"] = None,
+        StateValue: StateValue = None,
         ActionPrefix: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmsOutputTypeDef]:
         """
-        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
         """
 
 
 class GetMetricDataPaginator(Boto3Paginator):
     """
-    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
     """
 
     def paginate(
@@ -108,31 +108,31 @@ class GetMetricDataPaginator(Boto3Paginator):
         MetricDataQueries: List["MetricDataQueryTypeDef"],
         StartTime: datetime,
         EndTime: datetime,
-        ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
+        ScanBy: ScanBy = None,
         LabelOptions: LabelOptionsTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetMetricDataOutputTypeDef]:
         """
-        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
         """
 
 
 class ListDashboardsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
     """
 
     def paginate(
         self, DashboardNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDashboardsOutputTypeDef]:
         """
-        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
         """
 
 
 class ListMetricsPaginator(Boto3Paginator):
     """
-    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
     """
 
     def paginate(
@@ -140,9 +140,9 @@ class ListMetricsPaginator(Boto3Paginator):
         Namespace: str = None,
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
-        RecentlyActive: Literal["PT3H"] = None,
+        RecentlyActive: RecentlyActive = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListMetricsOutputTypeDef]:
         """
-        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
         """
